import hashlib
import random

def hash(text):
    text1 = text.encode()
    h = hashlib.sha512(text1)
    return int(h.hexdigest(), base=16)


def authrand():
    return random.randint(1, 10000000000000000000000000000000000000000)


def verify(rand, key, response):
    correct = hash(str(rand*key))
    return response == correct


def authenticte_self(key, rand):
    return hash(str(rand*key))




"""A python module that can easily authenticate remote computers.

See:
https://github.com/noah560/EasyAuth
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
import pathlib

here = pathlib.Path(__file__).parent.resolve()

# Get the long description from the README file
long_description = (here / "README.md").read_text(encoding="utf-8")


setup(
    name="SuperDuperEasyAuth",
    version="0.2.1",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/noah560/EasyAuth",
    author="Noah C. C. S.",
    author_email="noahisontheinternet@outlook.com",
    install_requires=[]
)
